asn1_* renamed into asn_*


git-svn-id: https://asn1c.svn.sourceforge.net/svnroot/asn1c/trunk@446 59561ff5-6e30-0410-9f3c-9617f08c8826
diff --git a/skeletons/constr_SET_OF.h b/skeletons/constr_SET_OF.h
index b013dd6..72de815 100644
--- a/skeletons/constr_SET_OF.h
+++ b/skeletons/constr_SET_OF.h
@@ -7,16 +7,16 @@
 
 #include <asn_application.h>
 
-typedef struct asn1_SET_OF_specifics_s {
+typedef struct asn_SET_OF_specifics_s {
 	/*
 	 * Target structure description.
 	 */
 	int struct_size;	/* Size of the target structure. */
-	int ctx_offset;		/* Offset of the ber_dec_ctx_t member */
+	int ctx_offset;		/* Offset of the asn_struct_ctx_t member */
 
 	/* XER-specific stuff */
 	int as_XMLValueList;	/* The member type must be encoded like this */
-} asn1_SET_OF_specifics_t;
+} asn_SET_OF_specifics_t;
 
 /*
  * A set specialized functions dealing with the SET OF type.